/***********************************************************************
*
* Copyright (c) 2021-2024 Barbara Geller and Ansel Sermersheim
*
* This example is free software, released under the BSD 2-Clause license.
* For license details refer to LICENSE provided with this project.
*
* CopperSpice is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
* https://opensource.org/licenses/BSD-2-Clause
*
***********************************************************************/

#include <QtCore>
#include <QtGui>

class MainWindow : public QWidget
{
 public:
   MainWindow();

 private:
   void prepareCommandLine(const QStringList &arguments);
   QCommandLineParser m_parser;
};

MainWindow::MainWindow()
{
   QStringList argList = QCoreApplication::arguments();

   QString appName     = argList.takeFirst();
   QString commandLine = argList.join(",  ");

   prepareCommandLine( {appName, "other_A", "other_B"} );
   const QStringList args = m_parser.positionalArguments();

   //
   setMinimumSize(400, 200);

   QLabel *label_1 = new QLabel();
   label_1->setText("Application Name:  " + appName);

   QLabel *label_2 = new QLabel();
   label_2->setText("Command Line Arguments:  " + commandLine);

   QLabel *label_3 = new QLabel();
   label_3->setText("Extra Positional Argument 1:  " + args[0]);

   QLabel *label_4 = new QLabel();
   label_4->setText("Extra Positional Argument 2:  " + args[1]);

   QPushButton *close_pb = new QPushButton();
   close_pb->setText("Close");

   QVBoxLayout *layout1 = new QVBoxLayout();
   layout1->setContentsMargins(20, 20, 20, 20);
   layout1->addWidget(label_1);
   layout1->addSpacing(20);
   layout1->addWidget(label_2);
   layout1->addSpacing(20);
   layout1->addWidget(label_3);
   layout1->addSpacing(20);
   layout1->addWidget(label_4);
   layout1->addStretch();

   QHBoxLayout *layout2 = new QHBoxLayout();
   layout2->addStretch();
   layout2->addWidget(close_pb);
   layout2->addStretch();

   QVBoxLayout *layoutMain = new QVBoxLayout(this);
   layoutMain->setContentsMargins(50, 55, 80, 15);
   layoutMain->addLayout(layout1);
   layoutMain->addSpacing(75);
   layoutMain->addLayout(layout2);

   connect(close_pb, &QPushButton::clicked, this, &QWidget::close);
}

void MainWindow::prepareCommandLine(const QStringList &arguments)
{
   m_parser.addPositionalArgument("extra_arg_1", "");
   m_parser.addPositionalArgument("extra_arg_2", "");

   m_parser.process(arguments);
}

int main(int argc, char *argv[])
{
   QApplication app(argc, argv);

   MainWindow *window = new MainWindow();
   window->show();

   return app.exec();
}
